@@ -1,16 +1,17 @@
-#' Function to return colour palletes functions from 'cpt-city'
+#' Function to return colour palettes functions from 'cpt-city'
 #'
-#' This function return a collor pallete based on the name or position of the
-#' pallete.
+#' This function return a collor palette based on the name or position of the
+#' palette.
 #'
 #' The cpt-city web archive comes from:
 #' http://soliton.vm.bytemark.co.uk/pub/cpt-city/index.html
 #'
-#' @param pal Pallete of colors available or the number of the position
+#' @param pal Palette of colors available or the number of the position
 #' @param n integer; number of colors
-#' of the same
+#' @param colorRampPalette Logical; to be used in sf and mapview.
 #'
-#' @return A colour pallete function.
+#'
+#' @return A colour palette function.
 #' @importFrom grDevices rgb colorRampPalette
 #' @export
 #' @examples {
@@ -29,12 +30,16 @@
 #'  scale_fill_gradientn(colours = cpt(n = 100))
 #' }
 #' }
-cpt <- function(pal = "mpl_inferno", n = 100){
+cpt <- function(pal = "mpl_inferno", n = 100, colorRampPalette = FALSE){
   m <- sysdata[[pal]]
   col <-  rgb(red = m$r, green = m$g, blue = m$b,
               maxColorValue = max(c(max(m$r, na.rm = T),
                                     max(m$g, na.rm = T),
                                     max(m$b, na.rm = T)))
               )
-  grDevices::colorRampPalette(col)(n)
+  if(colorRampPalette == FALSE){
+    return(grDevices::colorRampPalette(col)(n))
+  } else{
+    return(grDevices::colorRampPalette(col))
+  }
 }
